;; Generated package description from mode: lisp-data; .el  -*- jinxno-byte-compile: t -*-
(define-package "jinx" "2.1" "Enchanted Spell Checker" '((emacs "28.1") (compat "30")) :commit "84fc35aedddfbf24de144245fe9d1c8a61852f7a" :authors '(("Daniel Mendler" . "mail@daniel-mendler.de")) :maintainer '("Daniel Mendler" . "mail@daniel-mendler.de") :keywords '("convenience" "text") :url "https://github.com/minad/jinx")
